<p align="center">
  <img src="http://i.imgur.com/XZFkFei.png" alt="NxEnabled"/>
</p>

## What is NxEnabled?

It's a fairly common case, when the `enabled` state of button depends on some textable elements such as TextView, TextField. So this library allows the simplest way to achive this purpose with only few lines of code.

## Getting started :rocket:

Typical login screen with short, beautiful validation code:

```swift
loginButton.isEnabled(by: usernameTextField, passwordTextField) { username, password in
    username.characters.count > 5 && password.characters.count > 5
}
```

you can also combine together `UITextView` with `UITextField`'s:

```swift
signUpButton.isEnabled(by: firstnameTextField, lastnameTextField, bioTextView) { firstname, lastname, bio in
    return /* validation value */
}
```

### NOTE:
**One important case is that you should clear button's bag. It removes all observers from textable elements. Usually it needs to do in `deinit` method.**

```swift
deinit {
    signUpButton.clearBag()
}
```

## Installation :fire:

#### CocoaPods

To integrate NxEnabled, simply add the following line to your `Podfile`:

```ruby
pod "NxEnabled"
```

#### Carthage

To integrate NxEnabled into your Xcode project using Carthage, specify it in your `Cartfile`:

```ogdl
github "Otbivnoe/NxEnabled"
```

Run `carthage update` to build the framework and drag the built `NxEnabled.framework` into your Xcode project.

## Author :muscle:

Nikita Ermolenko, gnod94@gmail.com

## License :exclamation:

Framezilla is available under the MIT license. See the LICENSE file for more info.
